Class: Aws::CloudWatchRUM::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudWatchRUM::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudwatchrum/client.rb,
sig/client.rbs
Overview
An API client for CloudWatchRUM. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudWatchRUM::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCreateRumMetricDefinitionsResponseSuccess, _BatchDeleteRumMetricDefinitionsResponseSuccess, _BatchGetRumMetricDefinitionsResponseSuccess, _CreateAppMonitorResponseSuccess, _DeleteAppMonitorResponseSuccess, _DeleteResourcePolicyResponseSuccess, _DeleteRumMetricsDestinationResponseSuccess, _GetAppMonitorDataResponseSuccess, _GetAppMonitorResponseSuccess, _GetResourcePolicyResponseSuccess, _ListAppMonitorsResponseSuccess, _ListRumMetricsDestinationsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutResourcePolicyResponseSuccess, _PutRumEventsResponseSuccess, _PutRumMetricsDestinationResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAppMonitorResponseSuccess, _UpdateRumMetricDefinitionResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_create_rum_metric_definitions(params = {}) ⇒ Types::BatchCreateRumMetricDefinitionsResponse
Specifies the extended metrics and custom metrics that you want a CloudWatch RUM app monitor to send to a destination.
-
#batch_delete_rum_metric_definitions(params = {}) ⇒ Types::BatchDeleteRumMetricDefinitionsResponse
Removes the specified metrics from being sent to an extended metrics destination.
-
#batch_get_rum_metric_definitions(params = {}) ⇒ Types::BatchGetRumMetricDefinitionsResponse
Retrieves the list of metrics and dimensions that a RUM app monitor is sending to a single destination.
-
#create_app_monitor(params = {}) ⇒ Types::CreateAppMonitorResponse
Creates a Amazon CloudWatch RUM app monitor, which collects telemetry data from your application and sends that data to RUM.
-
#delete_app_monitor(params = {}) ⇒ Struct
Deletes an existing app monitor.
-
#delete_resource_policy(params = {}) ⇒ Types::DeleteResourcePolicyResponse
Removes the association of a resource-based policy from an app monitor.
-
#delete_rum_metrics_destination(params = {}) ⇒ Struct
Deletes a destination for CloudWatch RUM extended metrics, so that the specified app monitor stops sending extended metrics to that destination.
-
#get_app_monitor(params = {}) ⇒ Types::GetAppMonitorResponse
Retrieves the complete configuration information for one app monitor.
-
#get_app_monitor_data(params = {}) ⇒ Types::GetAppMonitorDataResponse
Retrieves the raw performance events that RUM has collected from your web application, so that you can do your own processing or analysis of this data.
-
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Use this operation to retrieve information about a resource-based policy that is attached to an app monitor.
-
#list_app_monitors(params = {}) ⇒ Types::ListAppMonitorsResponse
Returns a list of the Amazon CloudWatch RUM app monitors in the account.
-
#list_rum_metrics_destinations(params = {}) ⇒ Types::ListRumMetricsDestinationsResponse
Returns a list of destinations that you have created to receive RUM extended metrics, for the specified app monitor.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch RUM resource.
-
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Use this operation to assign a resource-based policy to a CloudWatch RUM app monitor to control access to it.
-
#put_rum_events(params = {}) ⇒ Struct
Sends telemetry events about your application performance and user behavior to CloudWatch RUM.
-
#put_rum_metrics_destination(params = {}) ⇒ Struct
Creates or updates a destination to receive extended metrics from CloudWatch RUM.
-
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
-
#update_app_monitor(params = {}) ⇒ Struct
Updates the configuration of an existing app monitor.
-
#update_rum_metric_definition(params = {}) ⇒ Struct
Modifies one existing metric definition for CloudWatch RUM extended metrics.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-cloudwatchrum/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1760 1761 1762 |
# File 'lib/aws-sdk-cloudwatchrum/client.rb', line 1760 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1763 1764 1765 |
# File 'lib/aws-sdk-cloudwatchrum/client.rb', line 1763 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#batch_create_rum_metric_definitions(params = {}) ⇒ Types::BatchCreateRumMetricDefinitionsResponse
Specifies the extended metrics and custom metrics that you want a CloudWatch RUM app monitor to send to a destination. Valid destinations include CloudWatch and Evidently.
By default, RUM app monitors send some metrics to CloudWatch. These default metrics are listed in CloudWatch metrics that you can collect with CloudWatch RUM.
In addition to these default metrics, you can choose to send extended metrics, custom metrics, or both.
-
Extended metrics let you send metrics with additional dimensions that aren't included in the default metrics. You can also send extended metrics to both Evidently and CloudWatch. The valid dimension names for the additional dimensions for extended metrics are
BrowserName,CountryCode,DeviceType,FileType,OSName, andPageId. For more information, see Extended metrics that you can send to CloudWatch and CloudWatch Evidently. -
Custom metrics are metrics that you define. You can send custom metrics to CloudWatch. CloudWatch Evidently, or both. With custom metrics, you can use any metric name and namespace. To derive the metrics, you can use any custom events, built-in events, custom attributes, or default attributes.
You can't send custom metrics to the
AWS/RUMnamespace. You must send custom metrics to a custom namespace that you define. The namespace that you use can't start withAWS/. CloudWatch RUM prependsRUM/CustomMetrics/to the custom namespace that you define, so the final namespace for your metrics in CloudWatch isRUM/CustomMetrics/your-custom-namespace.
The maximum number of metric definitions that you can specify in one
BatchCreateRumMetricDefinitions operation is 200.
The maximum number of metric definitions that one destination can contain is 2000.
Extended metrics sent to CloudWatch and RUM custom metrics are charged as CloudWatch custom metrics. Each combination of additional dimension name and dimension value counts as a custom metric. For more information, see Amazon CloudWatch Pricing.
You must have already created a destination for the metrics before you send them. For more information, see PutRumMetricsDestination.
If some metric definitions specified in a
BatchCreateRumMetricDefinitions operations are not valid, those
metric definitions fail and return errors, but all valid metric
definitions in the same operation still succeed.
87 |
# File 'sig/client.rbs', line 87 def batch_create_rum_metric_definitions: ( |
#batch_delete_rum_metric_definitions(params = {}) ⇒ Types::BatchDeleteRumMetricDefinitionsResponse
Removes the specified metrics from being sent to an extended metrics destination.
If some metric definition IDs specified in a
BatchDeleteRumMetricDefinitions operations are not valid, those
metric definitions fail and return errors, but all valid metric
definition IDs in the same operation are still deleted.
The maximum number of metric definitions that you can specify in one
BatchDeleteRumMetricDefinitions operation is 200.
103 |
# File 'sig/client.rbs', line 103 def batch_delete_rum_metric_definitions: ( |
#batch_get_rum_metric_definitions(params = {}) ⇒ Types::BatchGetRumMetricDefinitionsResponse
Retrieves the list of metrics and dimensions that a RUM app monitor is sending to a single destination.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
117 |
# File 'sig/client.rbs', line 117 def batch_get_rum_metric_definitions: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1733 1734 1735 1736 1737 1738 1739 1740 1741 1742 1743 1744 1745 1746 1747 1748 1749 |
# File 'lib/aws-sdk-cloudwatchrum/client.rb', line 1733 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudWatchRUM') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudwatchrum' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#create_app_monitor(params = {}) ⇒ Types::CreateAppMonitorResponse
Creates a Amazon CloudWatch RUM app monitor, which collects telemetry data from your application and sends that data to RUM. The data includes performance and reliability information such as page load time, client-side errors, and user behavior.
You use this operation only to create a new app monitor. To update an existing app monitor, use UpdateAppMonitor instead.
After you create an app monitor, sign in to the CloudWatch RUM console to get the JavaScript code snippet to add to your web application. For more information, see How do I find a code snippet that I've already generated?
131 |
# File 'sig/client.rbs', line 131 def create_app_monitor: ( |
#delete_app_monitor(params = {}) ⇒ Struct
Deletes an existing app monitor. This immediately stops the collection of data.
155 |
# File 'sig/client.rbs', line 155 def delete_app_monitor: ( |
#delete_resource_policy(params = {}) ⇒ Types::DeleteResourcePolicyResponse
Removes the association of a resource-based policy from an app monitor.
165 |
# File 'sig/client.rbs', line 165 def delete_resource_policy: ( |
#delete_rum_metrics_destination(params = {}) ⇒ Struct
Deletes a destination for CloudWatch RUM extended metrics, so that the specified app monitor stops sending extended metrics to that destination.
175 |
# File 'sig/client.rbs', line 175 def delete_rum_metrics_destination: ( |
#get_app_monitor(params = {}) ⇒ Types::GetAppMonitorResponse
Retrieves the complete configuration information for one app monitor.
187 |
# File 'sig/client.rbs', line 187 def get_app_monitor: ( |
#get_app_monitor_data(params = {}) ⇒ Types::GetAppMonitorDataResponse
Retrieves the raw performance events that RUM has collected from your web application, so that you can do your own processing or analysis of this data.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
198 |
# File 'sig/client.rbs', line 198 def get_app_monitor_data: ( |
#get_resource_policy(params = {}) ⇒ Types::GetResourcePolicyResponse
Use this operation to retrieve information about a resource-based policy that is attached to an app monitor.
221 |
# File 'sig/client.rbs', line 221 def get_resource_policy: ( |
#list_app_monitors(params = {}) ⇒ Types::ListAppMonitorsResponse
Returns a list of the Amazon CloudWatch RUM app monitors in the account.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
232 |
# File 'sig/client.rbs', line 232 def list_app_monitors: ( |
#list_rum_metrics_destinations(params = {}) ⇒ Types::ListRumMetricsDestinationsResponse
Returns a list of destinations that you have created to receive RUM extended metrics, for the specified app monitor.
For more information about extended metrics, see AddRumMetrics.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
244 |
# File 'sig/client.rbs', line 244 def list_rum_metrics_destinations: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Displays the tags associated with a CloudWatch RUM resource.
257 |
# File 'sig/client.rbs', line 257 def list_tags_for_resource: ( |
#put_resource_policy(params = {}) ⇒ Types::PutResourcePolicyResponse
Use this operation to assign a resource-based policy to a CloudWatch RUM app monitor to control access to it. Each app monitor can have one resource-based policy. The maximum size of the policy is 4 KB. To learn more about using resource policies with RUM, see Using resource-based policies with CloudWatch RUM.
268 |
# File 'sig/client.rbs', line 268 def put_resource_policy: ( |
#put_rum_events(params = {}) ⇒ Struct
Sends telemetry events about your application performance and user
behavior to CloudWatch RUM. The code snippet that RUM generates for
you to add to your application includes PutRumEvents operations to
send this data to RUM.
Each PutRumEvents operation can send a batch of events from one user
session.
279 |
# File 'sig/client.rbs', line 279 def put_rum_events: ( |
#put_rum_metrics_destination(params = {}) ⇒ Struct
Creates or updates a destination to receive extended metrics from CloudWatch RUM. You can send extended metrics to CloudWatch or to a CloudWatch Evidently experiment.
For more information about extended metrics, see BatchCreateRumMetricDefinitions.
308 |
# File 'sig/client.rbs', line 308 def put_rum_metrics_destination: ( |
#tag_resource(params = {}) ⇒ Struct
Assigns one or more tags (key-value pairs) to the specified CloudWatch RUM resource. Currently, the only resources that can be tagged app monitors.
Tags can help you organize and categorize your resources. You can also use them to scope user permissions by granting a user permission to access or change only resources with certain tag values.
Tags don't have any semantic meaning to Amazon Web Services and are interpreted strictly as strings of characters.
You can use the TagResource action with a resource that already has
tags. If you specify a new tag key for the resource, this tag is
appended to the list of tags associated with the alarm. If you specify
a tag key that is already associated with the resource, the new tag
value that you specify replaces the previous value for that tag.
You can associate as many as 50 tags with a resource.
For more information, see Tagging Amazon Web Services resources.
320 |
# File 'sig/client.rbs', line 320 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from the specified resource.
330 |
# File 'sig/client.rbs', line 330 def untag_resource: ( |
#update_app_monitor(params = {}) ⇒ Struct
Updates the configuration of an existing app monitor. When you use this operation, only the parts of the app monitor configuration that you specify in this operation are changed. For any parameters that you omit, the existing values are kept.
You can't use this operation to change the tags of an existing app monitor. To change the tags of an existing app monitor, use TagResource.
To create a new app monitor, use CreateAppMonitor.
After you update an app monitor, sign in to the CloudWatch RUM console to get the updated JavaScript code snippet to add to your web application. For more information, see How do I find a code snippet that I've already generated?
340 |
# File 'sig/client.rbs', line 340 def update_app_monitor: ( |
#update_rum_metric_definition(params = {}) ⇒ Struct
Modifies one existing metric definition for CloudWatch RUM extended metrics. For more information about extended metrics, see BatchCreateRumMetricsDefinitions.
362 |
# File 'sig/client.rbs', line 362 def update_rum_metric_definition: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1753 1754 1755 |
# File 'lib/aws-sdk-cloudwatchrum/client.rb', line 1753 def waiter_names [] end |