Class: Aws::CloudWatchRUM::Types::UpdateAppMonitorRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::CloudWatchRUM::Types::UpdateAppMonitorRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-cloudwatchrum/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#app_monitor_configuration ⇒ Types::AppMonitorConfiguration
A structure that contains much of the configuration data for the app monitor.
-
#custom_events ⇒ Types::CustomEvents
Specifies whether this app monitor allows the web client to define and send custom events.
-
#cw_log_enabled ⇒ Boolean
Data collected by RUM is kept by RUM for 30 days and then deleted.
-
#deobfuscation_configuration ⇒ Types::DeobfuscationConfiguration
A structure that contains the configuration for how an app monitor can deobfuscate stack traces.
-
#domain ⇒ String
The top-level internet domain name for which your application has administrative authority.
-
#domain_list ⇒ Array<String>
List the domain names for which your application has administrative authority.
-
#name ⇒ String
The name of the app monitor to update.
Instance Attribute Details
#app_monitor_configuration ⇒ Types::AppMonitorConfiguration
A structure that contains much of the configuration data for the app
monitor. If you are using Amazon Cognito for authorization, you must
include this structure in your request, and it must include the ID
of the Amazon Cognito identity pool to use for authorization. If you
don't include AppMonitorConfiguration, you must set up your own
authorization method. For more information, see Authorize your
application to send data to Amazon Web Services.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#custom_events ⇒ Types::CustomEvents
Specifies whether this app monitor allows the web client to define
and send custom events. The default is for custom events to be
DISABLED.
For more information about custom events, see Send custom events.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#cw_log_enabled ⇒ Boolean
Data collected by RUM is kept by RUM for 30 days and then deleted. This parameter specifies whether RUM sends a copy of this telemetry data to Amazon CloudWatch Logs in your account. This enables you to keep the telemetry data for more than 30 days, but it does incur Amazon CloudWatch Logs charges.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#deobfuscation_configuration ⇒ Types::DeobfuscationConfiguration
A structure that contains the configuration for how an app monitor can deobfuscate stack traces.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#domain ⇒ String
The top-level internet domain name for which your application has administrative authority.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#domain_list ⇒ Array<String>
List the domain names for which your application has administrative
authority. The UpdateAppMonitor allows either the domain or the
domain list.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the app monitor to update.
1939 1940 1941 1942 1943 1944 1945 1946 1947 1948 1949 |
# File 'lib/aws-sdk-cloudwatchrum/types.rb', line 1939 class UpdateAppMonitorRequest < Struct.new( :name, :domain, :domain_list, :app_monitor_configuration, :cw_log_enabled, :custom_events, :deobfuscation_configuration) SENSITIVE = [] include Aws::Structure end |